==> openGion6.4.4.1_src.zip: gf/src/org/opengion/fukurou/db/DBFunctionName.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.fukurou.db;

import java.util.Locale;
import java.util.Arrays;					// 6.3.9.1 (2015/11/27)
import org.opengion.fukurou.system.OgRuntimeException ;		// 6.4.2.0 (2016/01/29)

/**
 * 各データベースに対応するenum名を返します。
 * 主に、各データベースにおける関数名の差異を吸収するためのenumです。
 * 本来は、互換性のあるファンクション以外、使用しないようにしましょう。
 * また、無ければ互換性パックなどで、ファンクションを定義してしまうのも
 * 一つの方法です。
 *
 * <table border="1" frame="box" rules="all" >
 *  <caption>各データベースにおける関数</caption>
 *  <tr><th>データベース名 </th><th>連結</th><th>部分文字列</th><th>日付関数         </th></tr>
 *  <tr><td>{&#064;DBF.XXX}</td><td>CON </td><td>SUBSTR    </td><td>SYSDATE          </td></tr>
 *  <tr><td>ORACLE         </td><td>||  </td><td>SUBSTR    </td><td>SYSDATE          </td></tr>
 *  <tr><td>HSQL           </td><td>||  </td><td>SUBSTR    </td><td>CURRENT_TIMESTAMP</td></tr>
 *  <tr><td>POSTGRES       </td><td>||  </td><td>SUBSTR    </td><td>CURRENT_DATE     </td></tr>
 *  <tr><td>MYSQL          </td><td>||  </td><td>SUBSTR    </td><td>now()            </td></tr>
 *  <tr><td>SQLSERVER      </td><td>+   </td><td>SUBSTRING </td><td>GETDATE()        </td></tr>
 *  <tr><td>FIREBIRD       </td><td>||  </td><td>SUBSTR    </td><td>CURRENT_DATE     </td></tr>
 *  <tr><td>CACHE          </td><td>||  </td><td>SUBSTRING </td><td>SYSDATE          </td></tr>
 * </table>
 *
 * ※ MySQLでは、通常文字列連結は、CONCAT関数を使います。パイプ(||)で結合するには、
 * SET sql_mode='PIPES_AS_CONCAT' しておく必要があります。
 * JDBCで設定する場合は、jdbc:mysql://《サーバー》/《DB名》?sessionVariables=sql_mode='PIPES_AS_CONCAT'
 * と指定します。
 *
 * @og.rev 5.1.4.0 (2010/03/01) 新規作成
 * @og.rev 5.8.5.0 (2015/03/06) CACHE追加
 *
 * @version  5.0
 * @author   Kazuhiko Hasegawa
 * @since    JDK5.0,
 */
public enum DBFunctionName {
	// 引数付きenum定義：ここに、必要な関数が増えるたびに、追加していきます。
	// 6.2.2.1 (2015/03/31) SYSDATE 項目追加
	//			  CON	SUBSTR		  SYSDATE
	  ORACLE	( "||","SUBSTR"		, "SYSDATE" )
	, HSQL		( "||","SUBSTR"		, "CURRENT_TIMESTAMP" )		// 良く判らん
	, POSTGRES	( "||","SUBSTR"		, "CURRENT_DATE" )
	, MYSQL		( "||","SUBSTR"		, "now()" )					// SYSDATE() でもほとんど同じ
	, SQLSERVER	( "+" ,"SUBSTRING"	, "GETDATE()" )
	, FIREBIRD	( "||","SUBSTR"		, "CURRENT_DATE" )
	, CACHE		( "||","SUBSTRING"	, "SYSDATE" ) ; 			// 良く判らん

	private final String dbfCON ;
	private final String dbfSUBSTR ;
	private final String dbfSYSDATE ;							// 6.2.2.1 (2015/03/31) SYSDATE 項目追加

	/**
	 * コンストラクター(enum の場合は、private宣言される)
	 *
	 * @og.rev 5.1.4.0 (2010/03/01) 新規作成
	 * @og.rev 6.2.2.1 (2015/03/31) SYSDATE 項目追加
	 *
	 * @param	con   	第１引数にて指定(CON)
	 * @param	substr	第２引数にて指定(SUBSTR)
	 * @param	sysdt	第３引数にて指定(SYSDATE)
	 */
	private DBFunctionName( final String con , final String substr , final String sysdt ) {
		dbfCON    = con;
		dbfSUBSTR = substr;
		dbfSYSDATE= sysdt;
	}

	/**
	 * 共通ファンクションに対応するデータベース個別のファンクション名を返します。
	 *
	 * 現時点では、NAME,CON,SUBSTR のみ使用できます。
	 *
	 * @og.rev 5.1.4.0 (2010/03/01) 新規作成
	 * @og.rev 6.2.2.1 (2015/03/31) SYSDATE 項目追加
	 * @og.rev 6.3.9.1 (2015/11/27) メソッドの出口は、最後の１か所にすべきです(PMD)。
	 *
	 * @param   func 共通ファンクション
	 *
	 * @return  ファンクション名
	 */
	public String getFunctionName( final String func ) {
//		if( "NAME".equalsIgnoreCase(    func ) ) { return toString();	}
//		if( "CON".equalsIgnoreCase(     func ) ) { return dbfCON;		}
//		if( "SUBSTR".equalsIgnoreCase(  func ) ) { return dbfSUBSTR;	}
//		if( "SYSDATE".equalsIgnoreCase( func ) ) { return dbfSYSDATE;	}
//
//		return func;

		final String rtn ;
		if(      "NAME".equalsIgnoreCase(    func ) ) { rtn = toString();	}
		else if( "CON".equalsIgnoreCase(     func ) ) { rtn = dbfCON;		}
		else if( "SUBSTR".equalsIgnoreCase(  func ) ) { rtn = dbfSUBSTR;	}
		else if( "SYSDATE".equalsIgnoreCase( func ) ) { rtn = dbfSYSDATE;	}
		else {											rtn = func;			}

		return rtn ;
	}

	/**
	 * 各データベースに対応するファンクション名を返します。
	 *
	 * @og.rev 4.3.8.0 (2009/08/01) SUBSTRを追加
	 * @og.rev 5.1.2.0 (2010/01/01) MySQL対応,SUBSTRB廃止(帳票データの分割の内部処理化に伴う)
	 * @og.rev 5.1.4.0 (2010/03/01) データベース名 ではなく、dbid で判断するように変更
	 * @og.rev 5.7.7.2 (2014/06/20) DBF.NAME 時の処理の簡素化
	 * @og.rev 6.2.1.0 (2015/03/13) NAME だけ特殊処理するのではなく、統一する。
	 *
	 * @param   func ファンクション名(定義文字)
	 * @param   dbid 接続先ID
	 *
	 * @return  実ファンクション名
	 */
	public static String getFunctionName( final String func ,final String dbid ) {

		// 5.7.7.2 (2014/06/20) DBF.NAME 時の処理の簡素化
		final String dbName = ConnectionFactory.getDBName( dbid );
	// 6.2.1.0 (2015/03/13) NAME だけ特殊処理するのではなく、統一する。
	//	if( "NAME".equals( func ) ) { return dbName; }
	//	else {
			return getDBName( dbName ).getFunctionName( func );
	//	}

	}

	/**
	 * シーケンス名よりシーケンスオブジェクトを検索し、次の値を取り出します。
	 * DBに対するシーケンスオブジェクトは予め作成されている必要があります。
	 *
	 * また、MySQLの場合は、シーケンスオブジェクトが実装されていないため、
	 * 内部的には、引数のシーケンス名と同じ名前のテーブルから、Integer型の
	 * "SEQID"という項目名を検索することにより、シーケンスをエミュレートしています。
	 *
	 * @og.rev 5.1.9.0 (2010/08/01) 新規追加
	 * @og.rev 5.8.5.0 (2015/03/06) CACHE追加
	 *
	 * @param seqName シーケンス名
	 * @param tran トランザクション
	 *
	 * @return シーケンス番号
	 */
	public int getSequence( final String seqName, final Transaction tran ) {
		String sql = null;
		// 6.0.2.5 (2014/10/31) refactoring:無効な代入です。
		switch ( this ) {
			case ORACLE:
				sql = "select " + seqName + ".nextval from dual";
				break;
			case HSQL:
				sql = "select next value for " + seqName + " from dual";
				break;
			case POSTGRES:
				sql = "select nextval('" + seqName + "')";
				break;
			case MYSQL:
				sql = "update " + seqName + " set SEQID = last_insert_id(SEQID+1)";
				DBUtil.dbExecute( sql, new String[0], tran );
				sql = "select last_insert_id()";
				break;
			case SQLSERVER:
				throw new OgRuntimeException( "現在、SQLSERVERではシーケンス機能はサポートされていません。" );
			case FIREBIRD:
				sql = "select gen_id(" + seqName + ", 1) from rdb$database";
				break;
			// 5.8.5.0 (2015/03/06) CACHE追加
			case CACHE:
				throw new OgRuntimeException( "現在、CACHEではシーケンス機能はサポートされていません。" );
			default:
				throw new OgRuntimeException( "現在、このデータベースではシーケンス機能はサポートされていません。" );
		}

		// 6.0.2.5 (2014/10/31) refactoring:無効な代入です。
		final String[][] rtn = DBUtil.dbExecute( sql, new String[0], tran );
		return Integer.parseInt( rtn[0][0] );		// 6.0.2.4 (2014/10/17) メソッド間違い
	}

	/**
	 * 各データベースに対応するenum名を返します。
	 *
	 * @og.rev 5.1.4.0 (2010/03/01) 新規作成
	 * @og.rev 5.8.5.0 (2015/03/06) CACHE追加
	 * @og.rev 6.3.9.1 (2015/11/27) メソッドの出口は、最後の１か所にすべきです(PMD)。
	 *
	 * @param   dbName データベース名
	 *
	 * @return  データベースに対応するenum名
	 * @og.rtnNotNull
	 */
	public static DBFunctionName getDBName( final String dbName ) {
		final String dbn = dbName.toUpperCase( Locale.JAPAN );

//		if( 	 dbn.indexOf( "ORACLE"		) >= 0 ) { return DBFunctionName.ORACLE;	}
//		else if( dbn.indexOf( "HSQL"		) >= 0 ) { return DBFunctionName.HSQL;		}
//		else if( dbn.indexOf( "POSTGRES"	) >= 0 ) { return DBFunctionName.POSTGRES;	}
//		else if( dbn.indexOf( "MYSQL"		) >= 0 ) { return DBFunctionName.MYSQL;		}
//		else if( dbn.indexOf( "SQLSERVER"	) >= 0 ) { return DBFunctionName.SQLSERVER;	}
//		else if( dbn.indexOf( "FIREBIRD"	) >= 0 ) { return DBFunctionName.FIREBIRD;	}
//		else if( dbn.indexOf( "CACHE"		) >= 0 ) { return DBFunctionName.CACHE;		}	// 5.8.5.0 (2015/03/06)
//
//		final String errMsg = "初期化時に、指定の dbName キーが存在しません。"
//						+ "[" + dbn + "]" ;
//
//		throw new OgRuntimeException( errMsg );

		final DBFunctionName rtn ;
		if( 	 dbn.contains( "ORACLE"		) ) { rtn = DBFunctionName.ORACLE;		}
		else if( dbn.contains( "HSQL"		) ) { rtn = DBFunctionName.HSQL;		}
		else if( dbn.contains( "POSTGRES"	) ) { rtn = DBFunctionName.POSTGRES;	}
		else if( dbn.contains( "MYSQL"		) ) { rtn = DBFunctionName.MYSQL;		}
		else if( dbn.contains( "SQLSERVER"	) ) { rtn = DBFunctionName.SQLSERVER;	}
		else if( dbn.contains( "FIREBIRD"	) ) { rtn = DBFunctionName.FIREBIRD;	}
		else if( dbn.contains( "CACHE"		) ) { rtn = DBFunctionName.CACHE;		}	// 5.8.5.0 (2015/03/06)
		else {
			final String errMsg = "初期化時に、指定の dbName キーが存在しません。"
							+ "[" + dbName + "] キーは、" + Arrays.toString( DBFunctionName.values() ) ;

			throw new OgRuntimeException( errMsg );
		}

		return rtn;
	}
}

==> openGion6.8.4.2_src.zip: gf/src/org/opengion/fukurou/db/DBFunctionName.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.fukurou.db;

import java.util.Locale;
import java.util.Arrays;					// 6.3.9.1 (2015/11/27)
import org.opengion.fukurou.system.OgRuntimeException ;		// 6.4.2.0 (2016/01/29)

/**
 * 各データベースに対応するenum名を返します。
 * 主に、各データベースにおける関数名の差異を吸収するためのenumです。
 * 本来は、互換性のあるファンクション以外、使用しないようにしましょう。
 * また、無ければ互換性パックなどで、ファンクションを定義してしまうのも
 * 一つの方法です。
 *
 * <table border="1" frame="box" rules="all" >
 *  <caption>各データベースにおける関数</caption>
 *  <tr><th>データベース名 </th><th>連結</th><th>部分文字列</th><th>日付関数         </th></tr>
 *  <tr><td>{&#064;DBF.XXX}</td><td>CON </td><td>SUBSTR    </td><td>SYSDATE          </td></tr>
 *  <tr><td>ORACLE         </td><td>||  </td><td>SUBSTR    </td><td>SYSDATE          </td></tr>
 *  <tr><td>HSQL           </td><td>||  </td><td>SUBSTR    </td><td>CURRENT_TIMESTAMP</td></tr>
 *  <tr><td>POSTGRES       </td><td>||  </td><td>SUBSTR    </td><td>CURRENT_DATE     </td></tr>
 *  <tr><td>MYSQL          </td><td>||  </td><td>SUBSTR    </td><td>now()            </td></tr>
 *  <tr><td>SQLSERVER      </td><td>+   </td><td>SUBSTRING </td><td>GETDATE()        </td></tr>
 *  <tr><td>FIREBIRD       </td><td>||  </td><td>SUBSTR    </td><td>CURRENT_DATE     </td></tr>
 *  <tr><td>DERBY          </td><td>||  </td><td>SUBSTR    </td><td>CURRENT_TIMESTAMP</td></tr>
 *  <tr><td>CACHE          </td><td>||  </td><td>SUBSTRING </td><td>SYSDATE          </td></tr>
 *  <tr><td>H2             </td><td>||  </td><td>SUBSTR    </td><td>SYSDATE          </td></tr>
 *  <tr><td>OTHER          </td><td>||  </td><td>SUBSTR    </td><td>SYSDATE          </td></tr>
 * </table>
 *
 * ※ MySQLでは、通常文字列連結は、CONCAT関数を使います。パイプ(||)で結合するには、
 * SET sql_mode='PIPES_AS_CONCAT' しておく必要があります。
 * JDBCで設定する場合は、jdbc:mysql://《サーバー》/《DB名》?sessionVariables=sql_mode='PIPES_AS_CONCAT'
 * と指定します。
 *
 * @og.rev 5.1.4.0 (2010/03/01) 新規作成
 * @og.rev 5.8.5.0 (2015/03/06) CACHE追加
 *
 * @version  5.0
 * @author   Kazuhiko Hasegawa
 * @since    JDK5.0,
 */
public enum DBFunctionName {
	// 引数付きenum定義：ここに、必要な関数が増えるたびに、追加していきます。
	// 6.2.2.1 (2015/03/31) SYSDATE 項目追加
	//			  CON	SUBSTR		  SYSDATE
	  ORACLE	( "||","SUBSTR"		, "SYSDATE" )
	, HSQL		( "||","SUBSTR"		, "CURRENT_TIMESTAMP" )		// 良く判らん
	, POSTGRES	( "||","SUBSTR"		, "CURRENT_DATE" )
	, MYSQL		( "||","SUBSTR"		, "now()" )					// SYSDATE() でもほとんど同じ
	, SQLSERVER	( "+" ,"SUBSTRING"	, "GETDATE()" )
	, FIREBIRD	( "||","SUBSTR"		, "CURRENT_DATE" )
	, DERBY		( "||","SUBSTR"		, "CURRENT_TIMESTAMP" )		// 6.4.9.3 (2016/08/26)
	, CACHE		( "||","SUBSTRING"	, "SYSDATE" )	 			// 良く判らん
	, H2		( "||","SUBSTR"		, "SYSDATE" )	 			// 6.8.3.0 (2017/11/27) 追加
	, OTHER		( "||","SUBSTR"		, "SYSDATE" ) ; 			// 6.4.5.0 (2016/04/08) 適当

	private final String dbfCON ;
	private final String dbfSUBSTR ;
	private final String dbfSYSDATE ;							// 6.2.2.1 (2015/03/31) SYSDATE 項目追加

	/**
	 * コンストラクター(enum の場合は、private宣言される)
	 *
	 * @og.rev 5.1.4.0 (2010/03/01) 新規作成
	 * @og.rev 6.2.2.1 (2015/03/31) SYSDATE 項目追加
	 *
	 * @param	con   	第１引数にて指定(CON)
	 * @param	substr	第２引数にて指定(SUBSTR)
	 * @param	sysdt	第３引数にて指定(SYSDATE)
	 */
	private DBFunctionName( final String con , final String substr , final String sysdt ) {
		dbfCON    = con;
		dbfSUBSTR = substr;
		dbfSYSDATE= sysdt;
	}

	/**
	 * 共通ファンクションに対応するデータベース個別のファンクション名を返します。
	 *
	 * 現時点では、NAME,CON,SUBSTR のみ使用できます。
	 *
	 * @og.rev 5.1.4.0 (2010/03/01) 新規作成
	 * @og.rev 6.2.2.1 (2015/03/31) SYSDATE 項目追加
	 * @og.rev 6.3.9.1 (2015/11/27) メソッドの出口は、最後の１か所にすべきです(PMD)。
	 *
	 * @param   func 共通ファンクション
	 *
	 * @return  ファンクション名
	 */
	public String getFunctionName( final String func ) {
//		if( "NAME".equalsIgnoreCase(    func ) ) { return toString();	}
//		if( "CON".equalsIgnoreCase(     func ) ) { return dbfCON;		}
//		if( "SUBSTR".equalsIgnoreCase(  func ) ) { return dbfSUBSTR;	}
//		if( "SYSDATE".equalsIgnoreCase( func ) ) { return dbfSYSDATE;	}
//
//		return func;

		final String rtn ;
		if(      "NAME".equalsIgnoreCase(    func ) ) { rtn = toString();	}
		else if( "CON".equalsIgnoreCase(     func ) ) { rtn = dbfCON;		}
		else if( "SUBSTR".equalsIgnoreCase(  func ) ) { rtn = dbfSUBSTR;	}
		else if( "SYSDATE".equalsIgnoreCase( func ) ) { rtn = dbfSYSDATE;	}
		else {											rtn = func;			}

		return rtn ;
	}

	/**
	 * 各データベースに対応するファンクション名を返します。
	 *
	 * @og.rev 4.3.8.0 (2009/08/01) SUBSTRを追加
	 * @og.rev 5.1.2.0 (2010/01/01) MySQL対応,SUBSTRB廃止(帳票データの分割の内部処理化に伴う)
	 * @og.rev 5.1.4.0 (2010/03/01) データベース名 ではなく、dbid で判断するように変更
	 * @og.rev 5.7.7.2 (2014/06/20) DBF.NAME 時の処理の簡素化
	 * @og.rev 6.2.1.0 (2015/03/13) NAME だけ特殊処理するのではなく、統一する。
	 *
	 * @param   func ファンクション名(定義文字)
	 * @param   dbid 接続先ID
	 *
	 * @return  実ファンクション名
	 */
	public static String getFunctionName( final String func ,final String dbid ) {

		// 5.7.7.2 (2014/06/20) DBF.NAME 時の処理の簡素化
		final String dbName = ConnectionFactory.getDBName( dbid );
	// 6.2.1.0 (2015/03/13) NAME だけ特殊処理するのではなく、統一する。
	//	if( "NAME".equals( func ) ) { return dbName; }
	//	else {
			return getDBName( dbName ).getFunctionName( func );
	//	}

	}

	/**
	 * シーケンス名よりシーケンスオブジェクトを検索し、次の値を取り出します。
	 * DBに対するシーケンスオブジェクトは予め作成されている必要があります。
	 *
	 * また、MySQLの場合は、シーケンスオブジェクトが実装されていないため、
	 * 内部的には、引数のシーケンス名と同じ名前のテーブルから、Integer型の
	 * "SEQID"という項目名を検索することにより、シーケンスをエミュレートしています。
	 *
	 * @og.rev 5.1.9.0 (2010/08/01) 新規追加
	 * @og.rev 5.8.5.0 (2015/03/06) CACHE追加
	 * @og.rev 6.4.9.3 (2016/08/26) JavaDB(APACHE DERBY) の追加
	 *
	 * @param seqName シーケンス名
	 * @param tran トランザクション
	 *
	 * @return シーケンス番号
	 */
	public int getSequence( final String seqName, final Transaction tran ) {
		String sql = null;
		// 6.0.2.5 (2014/10/31) refactoring:無効な代入です。
		switch ( this ) {
			case ORACLE:
				sql = "select " + seqName + ".nextval from dual";
				break;
			case HSQL:
				sql = "select next value for " + seqName + " from dual";
				break;
			case POSTGRES:
				sql = "select nextval('" + seqName + "')";
				break;
			case MYSQL:
				sql = "update " + seqName + " set SEQID = last_insert_id(SEQID+1)";
				DBUtil.dbExecute( sql, new String[0], tran );
				sql = "select last_insert_id()";
				break;
			case SQLSERVER:
				throw new OgRuntimeException( "現在、SQLSERVERではシーケンス機能はサポートされていません。" );
			case FIREBIRD:
				sql = "select gen_id(" + seqName + ", 1) from rdb$database";
				break;
			// 6.4.9.3 (2016/08/26)
			case DERBY:
				throw new OgRuntimeException( "現在、DERBYではシーケンス機能はサポートされていません。" );
			// 5.8.5.0 (2015/03/06) CACHE追加
			case CACHE:
				throw new OgRuntimeException( "現在、CACHEではシーケンス機能はサポートされていません。" );
			default:
				throw new OgRuntimeException( "現在、このデータベースではシーケンス機能はサポートされていません。" );
		}

		// 6.0.2.5 (2014/10/31) refactoring:無効な代入です。
		final String[][] rtn = DBUtil.dbExecute( sql, new String[0], tran );
		return Integer.parseInt( rtn[0][0] );		// 6.0.2.4 (2014/10/17) メソッド間違い
	}

	/**
	 * 各データベースに対応するenum名を返します。
	 *
	 * @og.rev 5.1.4.0 (2010/03/01) 新規作成
	 * @og.rev 5.8.5.0 (2015/03/06) CACHE追加
	 * @og.rev 6.3.9.1 (2015/11/27) メソッドの出口は、最後の１か所にすべきです(PMD)。
	 * @og.rev 6.4.5.0 (2016/04/08) 規定以外のデータベースでも、動作するように、OTHER を用意する。
	 * @og.rev 6.4.9.3 (2016/08/26) JavaDB(APACHE DERBY) の追加
	 * @og.rev 6.8.3.0 (2017/11/27) H2 の追加
	 *
	 * @param   dbName データベース名
	 *
	 * @return  データベースに対応するenum名
	 * @og.rtnNotNull
	 */
	public static DBFunctionName getDBName( final String dbName ) {
		final String dbn = dbName.toUpperCase( Locale.JAPAN );

//		if( 	 dbn.indexOf( "ORACLE"		) >= 0 ) { return DBFunctionName.ORACLE;	}
//		else if( dbn.indexOf( "HSQL"		) >= 0 ) { return DBFunctionName.HSQL;		}
//		else if( dbn.indexOf( "POSTGRES"	) >= 0 ) { return DBFunctionName.POSTGRES;	}
//		else if( dbn.indexOf( "MYSQL"		) >= 0 ) { return DBFunctionName.MYSQL;		}
//		else if( dbn.indexOf( "SQLSERVER"	) >= 0 ) { return DBFunctionName.SQLSERVER;	}
//		else if( dbn.indexOf( "FIREBIRD"	) >= 0 ) { return DBFunctionName.FIREBIRD;	}
//		else if( dbn.indexOf( "CACHE"		) >= 0 ) { return DBFunctionName.CACHE;		}	// 5.8.5.0 (2015/03/06)
//
//		final String errMsg = "初期化時に、指定の dbName キーが存在しません。"
//						+ "[" + dbn + "]" ;
//
//		throw new OgRuntimeException( errMsg );

		final DBFunctionName rtn ;
		if( 	 dbn.contains( "ORACLE"		) ) { rtn = DBFunctionName.ORACLE;		}
		else if( dbn.contains( "HSQL"		) ) { rtn = DBFunctionName.HSQL;		}
		else if( dbn.contains( "POSTGRES"	) ) { rtn = DBFunctionName.POSTGRES;	}
		else if( dbn.contains( "MYSQL"		) ) { rtn = DBFunctionName.MYSQL;		}
		else if( dbn.contains( "SQLSERVER"	) ) { rtn = DBFunctionName.SQLSERVER;	}
		else if( dbn.contains( "FIREBIRD"	) ) { rtn = DBFunctionName.FIREBIRD;	}
		else if( dbn.contains( "DERBY"		) ) { rtn = DBFunctionName.DERBY;		}	// 6.4.9.3 (2016/08/26)
		else if( dbn.contains( "H2"			) ) { rtn = DBFunctionName.H2;			}	// 5.8.5.0 (2015/03/06)
		else if( dbn.contains( "CACHE"		) ) { rtn = DBFunctionName.CACHE;		}	// 5.8.5.0 (2015/03/06)
		else {
			rtn = DBFunctionName.OTHER;			// 6.4.5.0 (2016/04/08)
			final String errMsg = "初期化時に、指定の dbName キーが存在しません。"
							+ "[" + dbName + "] キーは、" + Arrays.toString( DBFunctionName.values() ) ;
			System.out.println( errMsg );
//			throw new OgRuntimeException( errMsg );
		}

		return rtn;
	}
}
